Learn R Programming

dbnR (version 0.3.3)

exact_inference: Performs exact inference forecasting with the GDBN over a data set

Description

Given a bn.fit object, the size of the net and a data.set, performs exact forecasting over the initial evidence taken from the data set.

Usage

exact_inference(dt, fit, size, obj_vars, ini, len)

Arguments

dt

data.table object with the TS data

fit

bn.fit object

size

number of time slices of the net

obj_vars

variables to be predicted

ini

starting point in the data set to forecast.

len

length of the forecast

Value

the results of the forecast