powered by
Learns a gaussian dynamic Bayesian network from a dataset. It allows the creation of markovian n nets rather than only markov 1.
learn_dbn_struc(dt, size = 2, ...)
the data.frame or data.table to be used
number of time slices of the net. Markovian 1 would be size 2
additional parameters for rsmax2 function
rsmax2
the structure of the net
# NOT RUN { data("motor") net <- learn_dbn_struc(motor, size = 3) # }
Run the code above in your browser using DataLab