predict.dbn.fit: Performs inference in every row of a dataset with a DBN
Description
Generic method for predicting a dataset with a "dbn.fit" S3 objects. Calls
predict_dt underneath.
Usage
# S3 method for dbn.fit
predict(object, ...)
Value
a data.table with the prediction results
Arguments
- object
a "dbn.fit" object
- ...
additional parameters for the inference process